<?php
/*
Plugin Name: Youtube shortcode
Plugin URI: http://wordpress.org/extend/plugins/youtube-shortcode
Description: Embed Youtube videos using shortcodes
Version: 1.7.2
Author: Túbal Martín
Author URI: http://margenn.com
License: GPL2

Copyright 2011  Túbal Martín  (email : tubalmartin@gmail.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License, version 2, as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
*/

if (!class_exists('Youtube_shortcode')):

class Youtube_shortcode {
	
	var $plugin_version = '172'; // version 1.7.2

	// Constructor / initialize plugin
	function Youtube_shortcode()
	{		
		// Load our shortcode only on the frontend
		if ( !is_admin() ) 
		{
			add_shortcode('youtube_sc', array($this, 'output_html'));
		}
		// Load admin functionality if there's a text editor
		else if ( in_array($GLOBALS['pagenow'], array('post.php', 'post-new.php')) ) 
		{ 
			add_action('admin_init', array($this, 'setup_tinymce_button'));
		}
	}


    static function encode_str($str)
    {
        return str_replace(array(' ', '"', "'", '=', '[', ']', '/'), array('%20', '%22', '%27', '%3D', '%5B', '%5D', '%2F'), (string) $str);
    }


    function decode_str($str)
    {
        return str_replace(array('%20', '%22', '%27', '%3D', '%5B', '%5D', '%2F'), array(' ', '"', "'", '=', '[', ']', '/'), (string) $str);
    }


	function output_html( $atts, $content = null )
	{
		$default_width  = '560';
		$default_height = '340';
        $default_title = 'YouTube video player';
	
		extract( shortcode_atts( array(
			// custom parameters
			'url' => '',
            'title' => $default_title, // SEO & WCAG 1.0+
			'width' => $default_width, // minimum: 200
			'height' => $default_height,
			'version' => '3',
			'nocookie' => '0', // privacy mode
			// Youtube's official player parameters & default values
			// Reference: http://code.google.com/intl/en/apis/youtube/player_parameters.html
			'autohide' => '2',
			'controls' => '1',
			'modestbranding' => '0',
			'origin' => '',
			'playlist' => '',
			'rel' => '1',
			'autoplay' => '0',
			'loop' => '0',
			'enablejsapi' => '0',
			'playerapiid' => '',
			'disablekb' => '0',
			'egm' => '0',
			'border' => '0',
			'color' => 'red',
			'color1' => 'b1b1b1',
			'color2' => 'cfcfcf',
			'start' => '',
			'theme' => 'dark',
			'fs' => '0',
			'hd' => '0',
			'showsearch' => '1',
			'showinfo' => '1',
			'iv_load_policy' => '1', // or 3
			'cc_load_policy' => '' // user's account setting. To force subtitles set to 1
		), $atts ) );
		
	   $url    = trim($url);
	   $title  = ($title != $default_title) ? htmlspecialchars($this->decode_str((string) $title)) : $default_title;
	   $width  = (int) $width < 200 ? '200' : $width;
	   $height = ($width != $default_width && $height == $default_height) ? (string) floor((int) $width / 1.66) : $height;
	   $tag    = in_the_loop() ? 'p' : 'div'; // Add support for Youtube shortcode in posts
	
	   $video_url = 'http://'.$this->get_server_host($url).'youtube' . ((bool) $nocookie ? '-nocookie' : '') . '.com/%s/'.$this->get_video_id($url).'?version='.$version.
		   ($autohide !== '2' ? '&amp;autohide=' . $autohide : '') .
		   (!(bool) $controls ? '&amp;controls=0' : '') .
		   ((bool) $modestbranding ? '&amp;modestbranding=1' : '') .
		   (!empty($origin) ? '&amp;origin=' . $origin : '') .
		   (!empty($playlist) ? '&amp;playlist=' . $playlist : '') .
		   (!(bool) $rel ? '&amp;rel=0' : '') .
		   ((bool) $autoplay ? '&amp;autoplay=1' : '') .
		   ((bool) $loop ? '&amp;loop=1' : '') .
		   ((bool) $enablejsapi ? '&amp;enablejsapi=1' : '') .
		   (!empty($playerapiid) ? '&amp;playerapiid=' . $playerapiid : '') .
		   ((bool) $disablekb ? '&amp;disablekb=1' : '') .
		   ((bool) $egm ? '&amp;egm=1' : '') .
		   ((bool) $border ? '&amp;border=1' : '') .
		   ($color != 'red' ? '&amp;color=' . $color : '') .
		   ($color1 != 'b1b1b1' ? '&amp;color1=0x' . $color1 : '') .
		   ($color2 != 'cfcfcf' ? '&amp;color2=0x' . $color2 : '') .
		   (!empty($start) ? '&amp;start=' . $start : '') .
		   ($theme != 'dark' ? '&amp;theme=' . $theme : '') .
		   ((bool) $fs ? '&amp;fs=1' : '') .
		   ((bool) $hd ? '&amp;hd=1' : '') .
		   (!(bool) $showsearch ? '&amp;showsearch=0' : '') .
		   (!(bool) $showinfo ? '&amp;showinfo=0' : '') .
		   ($iv_load_policy === '3' ? '&amp;iv_load_policy=' . $iv_load_policy : '') .
		   (!empty($cc_load_policy) ? '&amp;cc_load_policy=' . $cc_load_policy : '');
	
	   $flash_only_url = sprintf($video_url, 'v');
	   $flash_or_html5_url = sprintf($video_url, 'embed') . '&amp;wmode=transparent';
	
	   return  '<'.$tag.' class="youtube_sc" style="width:'.$width.'px; '. (!empty($height) ? 'height:'.$height.'px;' : '') . '">' .
				   '<noscript>' .
					   '<style type="text/css">.youtube_sc .youtube-player{width:0;height:0;display:none;}</style>' .
					   '<object width="'.$width.'" height="'.$height.'" title="'.$title.'">' .
								'<param name="movie" value="'.$flash_only_url.'"></param>' .
								((bool) $fs ? '<param name="allowfullscreen" value="true"></param>' : '') .
								'<param name="allowscriptaccess" value="always"></param>' .
								'<param name="wmode" value="transparent"></param>' .
								'<embed src="'.$flash_only_url.'" type="application/x-shockwave-flash" wmode="transparent" allowscriptaccess="always" ' . ((bool) $fs ? 'allowfullscreen="true"' : '') . 'width="'.$width.'" height="'.$height.'"></embed>' .
					   '</object>' .
					'</noscript>' .
					'<iframe title="'.$title.'" class="youtube-player" type="text/html" width="'.$width.'" height="'.$height.'" src="'.$flash_or_html5_url.'" frameborder="0"></iframe>' .
			   '</'.$tag.'>';
	}
	

	function get_video_id($url)
	{
		if (preg_match('/^http\:\/\/(?:(?:[a-zA-Z0-9\-\_\.]+\.|)youtube\.com\/watch\?v\=|youtu\.be\/)([a-zA-Z0-9\-\_]+)/i', $url, $matches) > 0) {
			return $matches[1];
		}
		else if (preg_match('/^([a-zA-Z0-9\-\_]+)$/i', $url, $matches) > 0) {
			return $matches[1];
		}
	
		return 'QRS8MkLhQmM'; // default video ID on error
	}
	
	
	function get_server_host($url)
	{
		if (preg_match('/^http\:\/\/([a-zA-Z0-9\-\_\.]+\.|)youtube\.com/i', $url, $matches)) {
			return $matches[1];
		}
	
		return 'www.';
	}
	
	// TinyMCE Button
	
	// Set up our TinyMCE button
	function setup_tinymce_button() 
	{
		if (get_user_option('rich_editing') == 'true' && current_user_can('edit_posts')) {
			add_filter('mce_external_plugins', array($this, 'add_tinymce_button_script'));
			add_filter('mce_buttons', array($this, 'register_tinymce_button')); 
		}
	}
	
	
	// Register our TinyMCE button
	function register_tinymce_button($buttons) {
		array_push($buttons, '|', 'Youtube_shortcode');
		return $buttons;
	}
	
	
	// Register our TinyMCE Script
	function add_tinymce_button_script($plugin_array) {
		$plugin_array['Youtube_shortcode'] = plugins_url('tinymcebutton.js.php?params='.$this->get_pop_up_params(), __FILE__);
		return $plugin_array;
	}
	
	
	function get_pop_up_params()
	{
		return urlencode(base64_encode(
			'plugin_version='.$this->plugin_version.'&'.
			'includes_url='.urlencode(includes_url()).'&'.
			'plugins_url='.urlencode(plugins_url()).'&'.
			'charset='.urlencode(get_option('blog_charset'))
		));
	}
	
}

// Create just one instance per page load
new Youtube_shortcode();

endif;